<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>Badges</name>
    <message>
        <location filename="../qml/pages/Badges.qml" line="18"/>
        <source>BADGES</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Checkin</name>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="18"/>
        <source>CHECK-IN DETAILS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="223"/>
        <source>TOTAL POINTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="261"/>
        <source>EARNED BADGES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="283"/>
        <source>COMMENTS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CheckinDialog</name>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="22"/>
        <source>NEW CHECK-IN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="48"/>
        <source>CHECK IN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="57"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="100"/>
        <source>Whats on your mind?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="129"/>
        <source>Sharing options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="133"/>
        <source>Share with Friends</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="141"/>
        <source>Post to Facebook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="149"/>
        <source>Post to Twitter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CheckinHistory</name>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="24"/>
        <source>CHECK-IN HISTORY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="64"/>
        <source>Load More</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommentDialog</name>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="26"/>
        <source>What is on your mind?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="38"/>
        <source>New awesome comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="69"/>
        <source>Comment!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="77"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DebugSubmit</name>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="18"/>
        <source>DEBUG SUBMIT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="34"/>
        <source>Thank you for submit!&lt;br&gt;This will be implemented soon!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="53"/>
        <source>SUBMIT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="61"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="92"/>
        <source>You can help me with Nelisquare development by submitting debug info.

The following information are going to be submitted:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="14"/>
        <source>Unknown %1 event!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="47"/>
        <source>This event type is unknown.
You can help with resolution.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FriendsFeed</name>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="43"/>
        <source>FRIENDS FEED</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="221"/>
        <source>RECENT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="234"/>
        <source>NEARBY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="255"/>
        <source>Load More</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="402"/>
        <source>Sorry, Pages are not supported yet :(</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="472"/>
        <source>Sorry, no lists support yet :(</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeaderBoard</name>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="19"/>
        <source>YOU ARE #</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="63"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LikeBox</name>
    <message>
        <location filename="../qml/components/LikeBox.qml" line="33"/>
        <source>USER LIKES</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListViewEx</name>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="9"/>
        <source>Pull and hold to refresh...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="10"/>
        <source>Release to refresh...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Login24sq</name>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="42"/>
        <source>Sign In to Foursquare</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Mayorships</name>
    <message>
        <location filename="../qml/pages/Mayorships.qml" line="19"/>
        <source>MAYORSHIPS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotificationDialog</name>
    <message>
        <location filename="../qml/components/NotificationDialog.qml" line="36"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Notifications</name>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="24"/>
        <source>NOTIFICATIONS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="51"/>
        <source>Mark all as read</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="58"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageWrapper</name>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="88"/>
        <source>Check updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="94"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="100"/>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Photo</name>
    <message>
        <location filename="../qml/pages/Photo.qml" line="20"/>
        <source>PHOTO</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhotoAdd</name>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="18"/>
        <source>Select photo for upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="56"/>
        <source>Error uploading photo!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhotoShareDialog</name>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="20"/>
        <source>PHOTO UPLOAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="36"/>
        <source>UPLOAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="86"/>
        <source>Sharing options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="90"/>
        <source>Public</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="97"/>
        <source>Post to Facebook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="104"/>
        <source>Post to Twitter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="48"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhotosBox</name>
    <message>
        <location filename="../qml/components/PhotosBox.qml" line="8"/>
        <source>PHOTOS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhotosGallery</name>
    <message>
        <location filename="../qml/pages/PhotosGallery.qml" line="13"/>
        <source>VENUE PHOTOS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingSlider</name>
    <message>
        <location filename="../qml/components/SettingSlider.qml" line="50"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="13"/>
        <source>updating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="21"/>
        <source>SETTINGS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="53"/>
        <source>2012-2013 Basil Semuonov</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="54"/>
        <source>Idea by Tommi Laukkanen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="55"/>
        <source>Shout out to @knobtviker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Design by Kim Venetvirta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="57"/>
        <source>If any problems, tweet @basil_s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="58"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="60"/>
        <source>Build</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="62"/>
        <source>Powered by Foursquare</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="64"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="70"/>
        <location filename="../qml/pages/Settings.qml" line="115"/>
        <source>Reset settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="71"/>
        <source>This action will erase all data including auth token, application settings and cache.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="72"/>
        <source>Yes, clear the data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="73"/>
        <source>No, thanks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="81"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="109"/>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="161"/>
        <source>UPDATES CHECK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="186"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="192"/>
        <source>Stable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="197"/>
        <source>Beta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="203"/>
        <source>Alpha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="209"/>
        <source>INTERVALS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="213"/>
        <source>GPS Unlock timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <source>Instant</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <source>%1 secs(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="222"/>
        <source>Feed autoupdate time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>%1 min(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="231"/>
        <source>PERMISSIONS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="234"/>
        <source>Allow use of Location Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="242"/>
        <source>Always run in background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="250"/>
        <source>Enable notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="258"/>
        <source>Feed at Home screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="266"/>
        <source>Push notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="317"/>
        <source>COLOR THEME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="336"/>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="342"/>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="348"/>
        <source>SCREEN ORIENTATION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="370"/>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="376"/>
        <source>Landscape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="381"/>
        <source>Portrait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="387"/>
        <source>STARTUP PAGE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="409"/>
        <source>Feed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="415"/>
        <source>Venues</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="420"/>
        <source>Self</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="426"/>
        <source>LANGUAGE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="437"/>
        <source>MAP PROVIDER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="460"/>
        <source>Nokia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="466"/>
        <source>Google</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="471"/>
        <source>OSM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="489"/>
        <source>IMAGE LOADING</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="508"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="513"/>
        <source>Cached</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="519"/>
        <source>INTEGRATION WITH APPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="525"/>
        <source>Download MOLO.ME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="544"/>
        <source>MOLO.ME Photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="564"/>
        <source>APPLICATION CACHE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="572"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="584"/>
        <source>Size: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="590"/>
        <source>UI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="593"/>
        <source>Reload UI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="599"/>
        <source>AUTHENTICATION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="602"/>
        <source>Reset authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="623"/>
        <source>ACCESS RATE LIMIT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="629"/>
        <source>API requests available: %1 / %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="635"/>
        <source>You are low on X-RATE requests</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="640"/>
        <source>DEBUG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="643"/>
        <source>Enable debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="657"/>
        <source>Options will be available soon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="672"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="673"/>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="674"/>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="675"/>
        <source>Debug</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpecialsList</name>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="13"/>
        <source>VENUE SPECIALS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="31"/>
        <source>Unlocked!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipDialog</name>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="40"/>
        <source>Write some cool tip here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="71"/>
        <source>ADD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipPage</name>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="22"/>
        <source>Usefull tip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="149"/>
        <source>TIP PHOTO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="171"/>
        <source>Save tip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="179"/>
        <source>Mark as done</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipsList</name>
    <message>
        <location filename="../qml/pages/TipsList.qml" line="18"/>
        <source>TIPS LIST</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="12"/>
        <source>New update available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="13"/>
        <source>Version: %1&lt;br&gt;Type: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="19"/>
        <source>Update!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="20"/>
        <source>No, thanks</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>User</name>
    <message>
        <location filename="../qml/pages/User.qml" line="59"/>
        <source>USER DETAILS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="270"/>
        <source>Add Friend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="282"/>
        <source>Approve Friend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="289"/>
        <source>Deny friend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="301"/>
        <source>Remove Friend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="314"/>
        <source>&lt;b&gt;SCORES&lt;/b&gt; (LAST 7 DAYS)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="319"/>
        <source>BEST SCORE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="377"/>
        <source>Badges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="412"/>
        <source>Checkins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="447"/>
        <source>Mayorships</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="482"/>
        <source>Friends</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="517"/>
        <source>Photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="553"/>
        <source>Tips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="569"/>
        <source>YOU ARE #</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="594"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UsersList</name>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="21"/>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="30"/>
        <source>USER FRIENDS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="33"/>
        <source>LIKERS LIST</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Venue</name>
    <message>
        <location filename="../qml/pages/Venue.qml" line="143"/>
        <source>VENUE PHOTOS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="251"/>
        <source>CHECK-IN HERE!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="273"/>
        <source>Venue doesn&apos;t have mayor yet!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>is the mayor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>It could be you!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="275"/>
        <source>%1 checkins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="317"/>
        <source>BEST TIPS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VenueAdd</name>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="91"/>
        <source>Venue name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VenueMap</name>
    <message>
        <location filename="../qml/pages/VenueMap.qml" line="186"/>
        <source>GET ROUTE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VenuesList</name>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="21"/>
        <source>NEARBY VENUES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="67"/>
        <source>GPS signal is fuzzy, cannot get your location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="96"/>
        <source>Tap to search place...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="107"/>
        <source>SEARCH</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Welcome</name>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="29"/>
        <source>Welcome!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="46"/>
        <source>Please, login with Foursquare!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="53"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="67"/>
        <source>Foursquare privacy policy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="81"/>
        <source>Nelisquare privacy policy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="108"/>
        <source>Location data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="109"/>
        <source>Nelisquare requires use of user location data. Data is needed to make geo-location services work properly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="110"/>
        <source>Allow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="111"/>
        <source>Deny</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="123"/>
        <source>Push notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="124"/>
        <source>Incoming push notifications are not supported at this version and are disabled by default.&lt;br/&gt;&lt;br/&gt;You will be promted again when they will be available at future versions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="128"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="161"/>
        <source>Check updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="167"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="173"/>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
